#-*- coding:utf-8 -*-

'''
Provides authentification and row access to Freebox using Freebox OS developer API.
Freebox API documentation : http://dev.freebox.fr/sdk/os/
'''

__version__ = '0.0.5'
__all__ = ['aiofreepybox']

from aiofreepybox.aiofreepybox import Freepybox
